#*************************************************************************************
#*CREATE OFFSHORE MEASURE - I.E. FOREIGN IMPORT AND EXPORT SHARE
#*
#*INPUT DATA: WIOT 2000-2014; 
#*            9_All_Industries.csv
#*            
#*
#*OUTPUT DATA: foreign export and import shares
#*             10_Offshoring.csv
#*
#*following: Antras 2012 - Measuring the Upstreamness of Produc...
#*************************************************************************************

# Libraries ----
library(readr); library(tidyverse); library(dplyr); library(ggplot2); 
library(gridExtra); library(readxl); library(stargazer); 
#library(matlib); library(plm); library(pscl);
select <- dplyr::select

#*************************************************************************************
# Data import ----
#*
#* importing data, preparing for further analysis
#*************************************************************************************

setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/original_WIOD_Data/WIOTS_in_R")
for(yearloop in 2000:2014){
  
  # Load data
  load(paste0("WIOT", yearloop, "_October16_ROW.RData"))

# make matrix with only country-industry pairs
ci_only <- wiot %>% 
  filter(Country != "TOT" | IndustryCode == "GO") %>% 
  select(-IndustryCode, -IndustryDescription, -Country, 
         -RNr, -Year, -TOT, 
         -colnames(wiot)[endsWith(colnames(wiot), "57")],
         -colnames(wiot)[endsWith(colnames(wiot), "58")],
         -colnames(wiot)[endsWith(colnames(wiot), "59")],
         -colnames(wiot)[endsWith(colnames(wiot), "60")],
         -colnames(wiot)[endsWith(colnames(wiot), "61")])

rownames(ci_only) <- c(colnames(ci_only), "GO")

ci_only$Country <- substr(rownames(ci_only), 1, 3)
ci_only$Industry <- substr(rownames(ci_only), 4, 5)

dim(ci_only) 

# Data other


# East and west EUROPE
ci_only$Europe_EW <- 0
ci_only$Europe_EW[which(ci_only$Country %in% 
                       c("BGR", "CYP", "CZE", 
                         "EST", "GRC", "HRV", 
                         "HUN", "LTU", "LVA",
                         "MLT", "POL", "ROU", 
                         "RUS", "SVK", "SVN" ))] <- "east"
ci_only$Europe_EW[which(ci_only$Country %in% 
                       c("AUT", "BEL", "CHE", 
                         "DEU", "DNK", "ESP", 
                         "FIN", "FRA", "GBR",
                         "IRL", "ITA", "LUX", "NLD", 
                         "NOR", "PRT", "SWE" ))] <- "west"
ci_only$Europe_EW <- as.factor(ci_only$Europe_EW)


# ASIA
ci_only$Asia <- 0
ci_only$Asia[which(ci_only$Country %in% 
                  c("CHN", "IDN", "IND", 
                    "JPN", "KOR", "TWN"))] <- "asia"
ci_only$Asia <- as.factor(ci_only$Asia)


# DEVELOPED
ci_only$Developed <- 0
ci_only$Developed[which(ci_only$Country %in% 
                       c("AUS", "AUT", "BEL", "BGR", "CAN",
                         "CHE", "CYP", "CZE", "DEU", "DNK", 
                         "ESP", "EST", "FIN", "FRA", "GBR",
                         "GRC", "HRV", "HUN", "IRL", "ITA", 
                         "JPN", "LTU", "LUX", "LVA", "MLT",
                         "NLD", "NOR", "POL", "PRT", "ROU", 
                         "SVK", "SVN", "SWE", "USA"))] <- 1
ci_only$Developed[which(ci_only$Country %in% 
                       c("BRA", "CHN", "IDN", "IND",
                         "KOR", "MEX", "RUS", "TUR", 
                         "TWN"))] <- 0
ci_only$Developed <- as.factor(ci_only$Developed)

# BRICS 0/1
ci_only$BRICS <- 0
ci_only$BRICS[which(ci_only$Country %in% c("BRA", "RUS", "IND", "CHN"))] <- 1
ci_only$BRICS <- as.factor(ci_only$BRICS)


# Paper 2 country groups

ci_only$ESW <- "Rest"
ci_only$ESW[which(ci_only$Country %in% c("BGR", "CZE", "EST", "GRC",
                                         "HRV", "HUN", "LTU", "LVA",
                                         "POL", "ROU", "SVK", "SVN"))] <- "East"

ci_only$ESW[which(ci_only$Country %in% c("BRA", "CHN", "IDN", "IND", 
                                         "KOR", "MEX"))] <- "South"

ci_only$ESW[which(ci_only$Country %in% c("AUS", "AUT", "BEL", "CAN", "CHE",
                                         "DEU", "DNK", "ESP", "FIN", "FRA", 
                                         "GBR", "IRL", "ITA", "JPN", "KOR",
                                         "NLD", "NOR", "PRT", "SWE", "TWN", 
                                         "USA"))] <- "North"


#*************************************************************************************
# Domestic imports and exports----
#*
#* 
#*************************************************************************************

# IMPORTS
data <- ci_only[-which(rownames(ci_only) == "GO"),]

for(i in 1:length(unique(data$Country))){

domestic <- unique(data$Country)[i]
domestic <- data[data$Country == domestic, 
                    startsWith(colnames(data), domestic)]
domestic_IM <- as.data.frame(sapply(domestic, sum))

colnames(domestic_IM) <- "IM_domestic"

ifelse(i == 1, 
       Imports <- domestic_IM,
       Imports <- rbind(Imports, domestic_IM))

print(i)

}

# EXPORTS

for(i in 1:length(unique(data$Country))){
  
  domestic <- unique(data$Country)[i]
  domestic <- data[data$Country == domestic, 
                      startsWith(colnames(data), domestic)]
  domestic_X <- as.data.frame(apply(domestic, 1, sum))
  
  colnames(domestic_X) <- "X_domestic"
  
  ifelse(i == 1, 
         Exports <- domestic_X,
         Exports <- rbind(Exports, domestic_X))
  
  print(i)
  
}


rm(domestic, domestic_IM, domestic_X)

#*************************************************************************************
# Other imports ----
#*
#* imports of intermediates from developed, BRICS, Asia, Europe etc countries 
#* this is including domestic supply too
#*************************************************************************************

#developed
developed <- ci_only[ci_only$Developed == 1,
                     sapply(ci_only, class) == "numeric"]
IM_developed <- as.data.frame(sapply(developed, sum))
colnames(IM_developed) <- "IM_developed"
Imports$IM_developed <- IM_developed$IM_developed

#developing
developing <- ci_only[ci_only$Developed == 0,
                     sapply(ci_only, class) == "numeric"]
IM_developing <- as.data.frame(sapply(developing, sum))
colnames(IM_developing) <- "IM_developing"
Imports$IM_developing <- IM_developing$IM_developing

#asia
asia <- ci_only[ci_only$Asia == "asia",
                     sapply(ci_only, class) == "numeric"]
IM_asia <- as.data.frame(sapply(asia, sum))
colnames(IM_asia) <- "IM_asia"
Imports$IM_asia <- IM_asia$IM_asia

#BRICS
BRICS <- ci_only[ci_only$BRICS == 1,
                     sapply(ci_only, class) == "numeric"]
IM_BRICS <- as.data.frame(sapply(BRICS, sum))
colnames(IM_BRICS) <- "IM_BRICS"
Imports$IM_BRICS <- IM_BRICS$IM_BRICS

#East Europe
EUeast <- ci_only[ci_only$Europe_EW == "east",
                 sapply(ci_only, class) == "numeric"]
IM_EUeast <- as.data.frame(sapply(EUeast, sum))
colnames(IM_EUeast) <- "IM_EUeast"
Imports$IM_EUeast <- IM_EUeast$IM_EUeast

#West Europe
EUwest <- ci_only[ci_only$Europe_EW == "west",
                  sapply(ci_only, class) == "numeric"]
IM_EUwest <- as.data.frame(sapply(EUwest, sum))
colnames(IM_EUwest) <- "IM_EUwest"
Imports$IM_EUwest <- IM_EUwest$IM_EUwest

#RoW
RoW <- ci_only[ci_only$Country == "ROW",
                  sapply(ci_only, class) == "numeric"]
IM_RoW <- as.data.frame(sapply(RoW, sum))
colnames(IM_RoW) <- "IM_RoW"
Imports$IM_RoW <- IM_RoW$IM_RoW

#US, CA, AU
UsCaAu <- ci_only[ci_only$Country %in% c("USA", "CAN", "AUS"),
                  sapply(ci_only, class) == "numeric"]
IM_UsCaAu <- as.data.frame(sapply(UsCaAu, sum))
colnames(IM_UsCaAu) <- "IM_UsCaAu"
Imports$IM_UsCaAu <- IM_UsCaAu$IM_UsCaAu


# Paper2

# east
east <- ci_only[ci_only$ESW == "East",
                  sapply(ci_only, class) == "numeric"]
IM_east <- as.data.frame(sapply(east, sum))
colnames(IM_east) <- "IM_east"
Imports$IM_east <- IM_east$IM_east
#south
south <- ci_only[ci_only$ESW == "South",
                sapply(ci_only, class) == "numeric"]
IM_south <- as.data.frame(sapply(south, sum))
colnames(IM_south) <- "IM_south"
Imports$IM_south <- IM_south$IM_south
#north
north <- ci_only[ci_only$ESW == "North",
                sapply(ci_only, class) == "numeric"]
IM_north <- as.data.frame(sapply(north, sum))
colnames(IM_north) <- "IM_north"
Imports$IM_north <- IM_north$IM_north
#rest
rest <- ci_only[ci_only$ESW == "Rest",
                sapply(ci_only, class) == "numeric"]
IM_rest <- as.data.frame(sapply(rest, sum))
colnames(IM_rest) <- "IM_rest"
Imports$IM_rest <- IM_rest$IM_rest


#*************************************************************************************
# Other exports ----
#*
#* exports of intermediates to country groups, BUT only for intermediate use 
#* not final use, inventory etc.
#*************************************************************************************

data <- ci_only[-which(rownames(ci_only) == "GO"),]
colnames(data) <- substr(colnames(data), 1, 3)


#developed
developed <- data[, colnames(data) %in% data$Cou[which(data$Dev == 1)]]
X_developed <- as.data.frame(apply(developed, 1, sum))
colnames(X_developed) <- "X_developed"
Exports$X_developed <- X_developed$X_developed

#developing
developing <- data[, colnames(data) %in% data$Cou[which(data$Dev == 0)]]
X_developing <- as.data.frame(apply(developing, 1, sum))
colnames(X_developing) <- "X_developing"
Exports$X_developing <- X_developing$X_developing

#asia
asia <- data[, colnames(data) %in% data$Cou[which(data$Asi == "asia")]]
X_asia <- as.data.frame(apply(asia, 1, sum))
colnames(X_asia) <- "X_asia"
Exports$X_asia <- X_asia$X_asia


#BRICS
BRICS <- data[, colnames(data) %in% data$Cou[which(data$BRI== 1)]]
X_BRICS <- as.data.frame(apply(BRICS, 1, sum))
colnames(X_BRICS) <- "X_BRICS"
Exports$X_BRICS <- X_BRICS$X_BRICS


#East Europe
EUeast <- data[, colnames(data) %in% data$Cou[which(data$Eur == "east")]]
X_EUeast <- as.data.frame(apply(EUeast, 1, sum))
colnames(X_EUeast) <- "X_EUeast"
Exports$X_EUeast <- X_EUeast$X_EUeast


#West Europe
EUwest <- data[, colnames(data) %in% data$Cou[which(data$Eur == "west")]]
X_EUwest <- as.data.frame(apply(EUwest, 1, sum))
colnames(X_EUwest) <- "X_EUwest"
Exports$X_EUwest <- X_EUwest$X_EUwest

#RoW
RoW <- data[, colnames(data) %in% data$Cou[which(data$Cou == "ROW")]]
X_RoW <- as.data.frame(apply(RoW, 1, sum))
colnames(X_RoW) <- "X_RoW"
Exports$X_RoW <- X_RoW$X_RoW

#US, CA, AU
UsCaAu <- data[, colnames(data) %in% data$Cou[which(data$Cou %in% c("USA", "CAN", "AUS"))]]
X_UsCaAu <- as.data.frame(apply(UsCaAu, 1, sum))
colnames(X_UsCaAu) <- "X_UsCaAu"
Exports$X_UsCaAu <- X_UsCaAu$X_UsCaAu

# Paper 2
#east
east <- data[, colnames(data) %in% data$Cou[which(data$ESW == "East")]]
X_east <- as.data.frame(apply(east, 1, sum))
colnames(X_east) <- "X_east"
Exports$X_east <- X_east$X_east
#south
south <- data[, colnames(data) %in% data$Cou[which(data$ESW == "South")]]
X_south <- as.data.frame(apply(south, 1, sum))
colnames(X_south) <- "X_south"
Exports$X_south <- X_south$X_south
#north
north <- data[, colnames(data) %in% data$Cou[which(data$ESW == "North")]]
X_north <- as.data.frame(apply(north, 1, sum))
colnames(X_north) <- "X_north"
Exports$X_north <- X_north$X_north
#rest
rest <- data[, colnames(data) %in% data$Cou[which(data$ESW == "Rest")]]
X_rest <- as.data.frame(apply(rest, 1, sum))
colnames(X_rest) <- "X_rest"
Exports$X_rest <- X_rest$X_rest



#*************************************************************************************
#* Narrow Offshoring (Hummels 2018) ----
#* 
#* OFF_i,i,t = A_i,i,t(M_i,t/Y_i,t)
#* 
#*************************************************************************************


Offshoring_narrow <- as.data.frame(cbind(Industry = as.numeric(rep(1:56, each = 44)), 
                           Country = rep(unique(substr(rownames(ci_only)[1:2464], 1, 3)), 56), 
                           Offshore_narrow = rep(NA, (dim(ci_only)[1]-1))))

i <- 0
for (r in 1:56) {
  
  d <- wiot %>% filter(RNr == r) %>% select(which(substr(colnames(wiot),4,5) == paste(r)))
  GO <- wiot %>% filter(IndustryCode == "GO") %>% select(which(substr(colnames(wiot),4,5) == paste(r)))
  
   for (c in 1:44) {
    A <- sum(d[,c])
    Offshoring_narrow$Offshore_narrow[c+(i*44)] <- A*((A-d[c,c])/GO[c])  
   }
   i <- i+1
}

rownames(Offshoring_narrow) <- paste0(Offshoring_narrow$Country, Offshoring_narrow$Industry)


#*************************************************************************************
# Combine X and IM and narrow Offshoring----
#*
#* combine the import and export data frames and add year variable and GO
#*************************************************************************************



Offshoring <- cbind(Imports, Exports, t(ci_only[rownames(ci_only) == "GO",
                                  sapply(ci_only, class) == "numeric"]))


Offshoring <- merge(Offshoring, Offshoring_narrow, by = "row.names")

Offshoring$Year <- yearloop


industry <- wiot %>% select(IndustryCode, RNr) %>% distinct() %>% 
  filter(RNr < 57)


Offshoring$Country <- substr(Offshoring$Row.names, 1, 3)
Offshoring$Industry <- substr(Offshoring$Row.names, 4, 7)
Offshoring <- merge(Offshoring, industry, by.x = "Industry", by.y = "RNr") %>% 
  select(-Industry)

ifelse(yearloop == 2000, 
       offshoring <- Offshoring,
       offshoring <- rbind(offshoring, Offshoring))

}



rm(Offshoring_narrow, Offshoring, Exports, Imports, industry,
   IM_asia, IM_BRICS, IM_developed, IM_developing, IM_RoW,
   X_asia, X_BRICS, X_developed, X_developing, X_RoW, 
   Domestic_share, BRICS, asia, data, 
   EUeast, EUwest, UsCaAu, X_EUeast, X_EUwest, IM_EUeast, 
   IM_EUwest, developed, developing, IM_developing, IM_UsCaAu, 
   RoW, wiot, X_UsCaAu, ci_only, i, yearloop,
   IM_east, IM_south, IM_north, IM_rest, X_east, X_south, X_north, X_rest,
   east, north, rest, south)


setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new")
write.csv(offshoring, "10_Offshoring.csv")

#*************************************************************************************
# Merge with data----
#*************************************************************************************

data <- as.data.frame(read_csv("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new/9_All_Industries.csv")) %>% 
  select(-"...1")
offshoring <- offshoring %>% select(-GO)


data <- merge(data, offshoring, 
      by.x = c("earliest_filing_year", "IndustryCode", "iso_alpha3"),
      by.y = c("Year", "IndustryCode", "Country"), all.x = TRUE)

data$Offshore_narrow <- as.numeric(data$Offshore_narrow)

#Export data ----
setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new")
write.csv(data, "10_Offshoring.csv")

rm(offshoring)

#*************************************************************************************
#* Functional specialisation (Timmer 2019) ----
#* industries dont match well...
#* 
#*************************************************************************************


