#******************************************************************************************************
#*APPLN_ID INDEX FROM PROCESS DATA TO SELECT APPLICATIONS IN PATSTAT 
#*
#*IMPORT: process_patents_epo.txt, process_patents_uspto.txt
#*EXPORT: process_patents_appln_id.csv
#*NOTES: 
#   -creates index-dataframe with unique appln_id to be merged with PATSTAT
#   -shows max and min years for earliest_filing_date, appln_filing_date, publn_date
      

#******************************************************************************************************
# Libraries----
library(dplyr); library(magrittr); library(readr)
#******************************************************************************************************
# Max & MIN year----

# finding the maximum year in process_patents data

process_patents_epo <- read_csv("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/original_Process_Product_Data/process_patents_epo.txt")
process_patents_uspto <- read_csv("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/original_Process_Product_Data/process_patents_uspto.txt")

# EPO data
unique(sort(process_patents_epo$earliest_filing_date, decreasing = T)) # 2017
unique(sort(process_patents_epo$appln_filing_date, decreasing = T)) # 2017
unique(sort(process_patents_epo$publn_date, decreasing = T)) # 2017

unique(sort(process_patents_epo$earliest_filing_date, decreasing = F)) # 1934
unique(sort(process_patents_epo$appln_filing_date, decreasing = F)) # 1978
unique(sort(process_patents_epo$publn_date, decreasing = F)) # 1978

# USPTO data
unique(sort(process_patents_uspto$earliest_filing_date, decreasing = T)) # 2017
unique(sort(process_patents_uspto$appln_filing_date, decreasing = T)) # 2017
unique(sort(process_patents_uspto$publn_date, decreasing = T)) # 2017


unique(sort(process_patents_uspto$earliest_filing_date, decreasing = F)) # 1790
unique(sort(process_patents_uspto$appln_filing_date, decreasing = F)) # 1790
unique(sort(process_patents_uspto$publn_date, decreasing = F)) # 1790

#******************************************************************************************************
# are there any entries for which appln_date or publn_date is prior earliest_filing_date?

# EPO data
process_patents_epo[ which(process_patents_epo$publn_date<process_patents_epo$earliest_filing_date),] 
          #only for 9999 in latter
process_patents_epo[ which(process_patents_epo$appln_filing_date<process_patents_epo$earliest_filing_date),]  
          #only for 9999 in latter

#USPTO data
process_patents_uspto[ which(process_patents_uspto$publn_date<process_patents_uspto$earliest_filing_date),] %>% 
       filter(earliest_filing_date <9999) %>% 
       arrange(earliest_filing_date) 
          # 194
process_patents_uspto[ which(process_patents_uspto$appln_filing_date<process_patents_uspto$earliest_filing_date),]  
          #only for 9999 in latter

#******************************************************************************************************
# Merge----

# merge EPO and USPTO
process_patents <- rbind(process_patents_epo,process_patents_uspto)

# create dataframe of unique appln_id (# of appln_id = 15,683,232)
process_patents_appln_id <- process_patents %>% 
                              select(appln_id) %>% 
                              distinct()

#******************************************************************************************************
# Export----

# export to Toshiba patstat SAS library
setwd("D:/PATSTAT")
write.csv(process_patents_appln_id, "process_patents_appln_id.csv")


