#*************************************************************************************
#* CPC-codes of Banholzer appln_ids
#*
#*INPUT DATA: process_patents_appln_id.csv, tls224_part01.csv, tls224_part02.csv
#*
#*OUTPUT DATA: cpc_codes_appln_id.csv
#*************************************************************************************

# Libraries ----

library(readr); library(tidyverse); library(dplyr); library(ggplot2); library(magrittr);
library(gridExtra); library(pscl); library(plm); library(stargazer)

#*************************************************************************************

# Set-up----

## Load data----

# appln_id from Banholzer data:
appln_id_pp <- read_csv("//tsclient/D/PATSTAT/process_patents_appln_id.csv") 
appln_id_pp <- appln_id_pp %>% select(-...1)
appln_id_pp <- appln_id_pp$appln_id

# tls224 from PATSTAT with cpc codes
tls224 <- read_csv("//tsclient/D/Autumn/tls224_part01.csv")
tls224_2 <- read_csv("//tsclient/D/Autumn/tls224_part02.csv")

## Merge data----

tls224 <- tls224 %>% 
              filter(appln_id %in% appln_id_pp)

tls224_2 <- tls224_2 %>% 
              filter(appln_id %in% appln_id_pp)

tls224 <- rbind(tls224, tls224_2)

dim(tls224) # 64,655,626 rows

rm(tls224_2)

## Clean data----

# remove whitespace
tls224$cpc_class_symbol <- gsub(" ", "", tls224$cpc_class_symbol)

# Export data----
write.csv(tls224, "cpc_codes_appln_id.csv")
