#******************************************************************************************************
#*MERGE PROCESS_PATSTAT AND WIOT DATA 
#*
#*IMPORT: process_patstat.csv
          tls902_ipc_nace2.sas7bdat
          WIOTS_in_R
#*EXPORT: pp_wiot.csv
#*        Y02_pp_wiot.csv
#*NOTES: 
#*      - skript can be found on the server: 
#*           \\tsclient\C\Users\franziska.tinnefeld\OneDrive - Universit Cattolica del Sacro Cuore\Paper1\Skripts
#*
#******************************************************************************************************
# Libraries----

#sapply(c("dplyr", "magrittr", "readr", "haven"), install.packages)
library(dplyr); library(magrittr); library(readr); library(haven)
#******************************************************************************************************

# Set-up----

## Load Data----

### process_patstat data---- 
data <- read.csv("D:/Tinnefeld-user6/Data/4_output_data/process_patstat.csv")         # 17:10 - 17:35


nace2_description <- read_sas("D:/Tinnefeld-user6/Data/original_sas_PATSTAT/tls902_ipc_nace2.sas7bdat")
nace2_description <- nace2_description %>% 
                      select(nace2_code, nace2_descr) %>% 
                      distinct()

data <- merge(data, nace2_description, by = "nace2_code")
rm(nace2_description)

### WIOT data----
setwd("D:/Tinnefeld-user6/Data/original_WIOD_Data/WIOTS_in_R")

load("WIOT2000_October16_ROW.RData")
value_added <- data.frame("year" = rep(2000, length(colnames(wiot[which(wiot$IndustryCode=="VA"),])[-c(1:5)])))
value_added$country_industry <- colnames(wiot[which(wiot$IndustryCode=="VA"),])[-c(1:5)]
value_added$VA <- unlist(c(wiot[which(wiot$IndustryCode=="VA"),-c(1:5)]))
value_added$country <- substr(value_added$country_industry, 1, 3)
value_added$industry <- substr(value_added$country_industry, 4,5)
value_added <- merge(value_added, unique(wiot[,c(1,2,4)]), by.x = "industry", by.y = "RNr", all.x = TRUE, all.y = FALSE)
data_wiot <- value_added
total_output <- data.frame("year" = rep(2000, length(colnames(wiot[which(wiot$IndustryCode=="GO"),])[-c(1:5)])))
total_output$country_industry <- colnames(wiot[which(wiot$IndustryCode=="GO"),])[-c(1:5)]
total_output$GO <- unlist(c(wiot[which(wiot$IndustryCode=="GO"),-c(1:5)]))
total_output$country <- substr(total_output$country_industry, 1, 3)
total_output$industry <- substr(total_output$country_industry, 4,5)
total_output <- merge(total_output, unique(wiot[,c(1,2,4)]), 
                      by.x = "industry", by.y = "RNr", all.x = TRUE, all.y = FALSE)
total_output <- total_output %>% select(year, industry, country, country_industry, GO, IndustryDescription, IndustryCode)

data_wiot <- merge(value_added, total_output, by = c("industry","year","country_industry",
                                                     "country","IndustryCode","IndustryDescription")) %>% 
  mutate(VA_share = VA/GO) %>% 
  select(year, country_industry, country, industry, VA, GO, VA_share, 
         IndustryCode, IndustryDescription)
data_wiot$VA_share[is.na(data_wiot$VA_share)] <- 0



for(i in 2001:2014){
# Merge WIOT Years----
  load(paste0("WIOT",i, "_October16_ROW.RData"))
  
  value_added <- data.frame("year" = rep(i, length(colnames(wiot[which(wiot$IndustryCode=="VA"),])[-c(1:5)])))
  value_added$country_industry <- colnames(wiot[which(wiot$IndustryCode=="VA"),])[-c(1:5)]
  value_added$VA <- unlist(c(wiot[which(wiot$IndustryCode=="VA"),-c(1:5)]))
  value_added$country <- substr(value_added$country_industry, 1, 3)
  value_added$industry <- substr(value_added$country_industry, 4,5)
  value_added <- merge(value_added, unique(wiot[,c(1,2,4)]), by.x = "industry", by.y = "RNr", all.x = TRUE, all.y = FALSE)
  
  total_output <- data.frame("year" = rep(i, length(colnames(wiot[which(wiot$IndustryCode=="GO"),])[-c(1:5)])))
  total_output$country_industry <- colnames(wiot[which(wiot$IndustryCode=="GO"),])[-c(1:5)]
  total_output$GO <- unlist(c(wiot[which(wiot$IndustryCode=="GO"),-c(1:5)]))
  total_output$country <- substr(total_output$country_industry, 1, 3)
  total_output$industry <- substr(total_output$country_industry, 4,5)
  total_output <- merge(total_output, unique(wiot[,c(1,2,4)]), 
                        by.x = "industry", by.y = "RNr", all.x = TRUE, all.y = FALSE)
  total_output <- total_output %>% select(year, industry, country, country_industry, GO, IndustryDescription, IndustryCode)
  
  value_added <- merge(value_added, total_output, by = c("industry","year","country_industry",
                                                         "country","IndustryCode","IndustryDescription")) %>% 
    mutate(VA_share = VA/GO) %>% 
    select(year, country_industry, country, industry, VA, GO, VA_share, 
           IndustryCode, IndustryDescription)
  
  data_wiot <- rbind(data_wiot, value_added)
  data_wiot$VA_share[is.na(data_wiot$VA_share)] <- 0
}
rm(wiot, value_added, total_output, i)



#******************************************************************************************************
# Merge----

## Industry concordance----


"aggregation in WIOT and in PATSTAT of the nace2 codes are different"
    "WIOT CLASSIFICATION IS MORE BROAD meaning several patstat NACE2_codes into one WIOT class"


#*********************************some statistics
setwd("D:/Tinnefeld-user6/Rsinks")
sink("5_merge_pp_wiot.txt", append = FALSE)

        "Number of patstat nace2 codes"
length(unique(data$nace2_code)) #84
        "Number of WIOT nace2 codes"
length(unique(data_wiot$IndustryCode)) #57


"Industries:"
        "PATSTAT"
print(data %>% select(nace2_code, nace2_descr) %>% distinct())

        "WIOT"
print(data_wiot %>% select(IndustryCode, IndustryDescription) %>% distinct())


"how many appln_id in each class?"
print(data %>% group_by(nace2_code) %>% select(appln_id) %>% distinct() %>% count(), n=100)

"how many docdb_family_id in each class?"
print(data %>% group_by(nace2_code) %>% select(docdb_family_id) %>% distinct() %>% count(), n=100)

"how many nace2_codes on average per appln_id"
data %>% select(appln_id, nace2_code) %>% distinct() %>% group_by(appln_id) %>% count() %>% ungroup() %>% summarise(mean = mean(n))
"how many nace2_codes on average per docdb_family_id"
data %>% select(docdb_family_id, nace2_code) %>% distinct() %>% group_by(docdb_family_id) %>% count() %>% ungroup() %>% summarise(mean = mean(n))
sink()
#*********************************


# make concordance
        "I group patstat nace codes to WIOT codes"
data$IndustryCode <- NA
data$IndustryCode[which(data$nace2_code %in% c(10, 10.5, 11, 12))] <- "C10-C12"
data$IndustryCode[which(data$nace2_code %in% c(13, 14, 15))] <- "C13-C15"
data$IndustryCode[which(data$nace2_code %in% 
                          c(16, 17, 19, 21, 30))] <- paste0("C", data$nace2_code[which(data$nace2_code %in% 
                                                                                         c(16, 17, 19, 21, 30))])
data$IndustryCode[which(data$nace2_code == 18.1)] <- "C18"
data$IndustryCode[which(data$nace2_code %in% 
                          c(20.1, 20.2, 20.3, 20.4, 20.42, 20.5, 20.51, 20.52, 20.6))] <- "C20"
data$IndustryCode[which(data$nace2_code %in% 
                          c(22, 22.1, 22.2))] <- "C22"
data$IndustryCode[which(data$nace2_code %in% 
                          c(23, 23.1, 23.3, 23.42, 23.5))] <- "C23"
data$IndustryCode[which(data$nace2_code %in% 
                          c(24, 24.46))] <- "C24"
data$IndustryCode[which(data$nace2_code %in% 
                          c(25.1, 25.2, 25.3, 25.4, 25.5, 25.6, 25.7, 25.9, 25.94))] <- "C25"
data$IndustryCode[which(data$nace2_code %in% 
                          c(26.1, 26.11, 26.2, 26.3, 26.4, 26.5, 26.51, 26.52, 
                            26.6, 26.7, 26.8))] <- "C26"
data$IndustryCode[which(data$nace2_code %in% 
                          c(27.1, 27.12, 27.2, 27.3, 27.33, 27.4, 27.5, 27.9))] <- "C27"
data$IndustryCode[which(data$nace2_code %in% 
                          c(28.1, 28.11, 28.14, 28.21, 28.22, 28.23, 
                            28.25, 28.29, 28.3, 28.4, 
                            28.9, 28.92, 28.94, 28.95, 28.99))] <- "C28"
data$IndustryCode[which(data$nace2_code %in% 
                          c(29.1, 29.3))] <- "C29"
data$IndustryCode[which(data$nace2_code %in% 
                          c(31, 32, 32.5, 32.9))] <- "C31_C32"
data$IndustryCode[which(data$nace2_code %in% c(42.2, 42.91, 43))] <- "F"
data$IndustryCode[which(data$nace2_code %in% c(62))] <- "J62_J63"


#*********************************some statistics
setwd("D:/Tinnefeld-user6/Rsinks")
sink("5_merge_pp_wiot.txt", append = TRUE)
"head and tail of data"
head(data)
tail(data)
"random pick from 2014"
head(data %>% arrange(appln_id) %>% filter(earliest_filing_year == 2014))

"how many WIOT_nace classes are there in PATSTAT?"
length(unique(data$IndustryCode))

"how many nace_wiot_codes on average per appln_id"
data %>% select(appln_id, IndustryCode) %>% distinct() %>% group_by(appln_id) %>% count() %>% ungroup() %>% summarise(mean = mean(n))
"how many nace_wiot_codes on average per docdb_family_id"
data %>% select(docdb_family_id, IndustryCode) %>% distinct() %>% group_by(docdb_family_id) %>% count() %>% ungroup() %>% summarise(mean = mean(n))
sink()
#*********************************

## Country concordance----


#**********************************
setwd("D:/Tinnefeld-user6/Rsinks")
sink("5_merge_pp_wiot.txt", append = T)
"Concordance between country codes of Patstat and WIOT needs to be checked"
"Also: PATSTAT countries not present in WIOT will be classified as ROW countries"
length(unique(data$iso_alpha3))# 218
length(unique(data_wiot$country)) # 45
unique(data$iso_alpha3)
unique(data_wiot$country)
unique(data_wiot$country)[-which(unique(data_wiot$country) %in% unique(data$iso_alpha3))]
sink()
#**********************************

data$country <- "ROW"
data$country[which(is.na(data$iso_alpha3))] <- NA
data$country[which(data$iso_alpha3 %in% 
                     unique(data_wiot$country))] <- data$iso_alpha3[which(data$iso_alpha3 %in% 
                                                                            unique(data_wiot$country))]


## Merge WIOT on PATSTAT----

data <- merge(data, data_wiot, 
                   by.x = c("earliest_filing_year", "IndustryCode", "country"), 
                   by.y = c("year", "IndustryCode", "country"), 
                   all.x = T, all.y = F)

### Clean----
data <- data %>% filter(earliest_filing_date < 2015)

data <- data %>% select(appln_id,publn_nr,
                        
                        appln_kind,appln_publn_auth,
                        appln_filing_year, earliest_filing_year, publn_date,
                        publn_kind,ipr_type,granted,publn_first_grant,
                        
                        pat_publn_id,docdb_family_id,docdb_family_size, nb_citing_docdb_fam,
                       
                        nb_applicants,nb_inventors,
                        person_id,psn_sector,
                        person_ctry_code,iso_alpha3,st3_name,country, eu_member, epo_member,oecd_member,
                        
                        Y02,Y02PN,
                        
                        publn_claims,
                        total_count,total_count_ind,
                        process_ratio_2_ind,process_ratio_5_ind,
                        process_use_ratio_pred,process_use_ratio_pred_ind,
                        use_ratio,use_ratio_ind,
                        product_by_process_ratio_2,product_by_process_ratio_2_ind,
                        title_process,title_use,
                        abstract_process,abstract_use,abstract_process_use_pred,
                        
                        nace2_code,nace2_descr,weight,
                        IndustryCode,IndustryDescription,VA,GO,VA_share) %>% 
                  distinct()


# NA that stand for Namibia have been overwritten with is.na values
  # therefore change NA code to NN
    data$person_ctry_code[which(data$iso_alpha3 == "NAM")] <- "NN"

# remove those patents that have NA in country data
    
    #number of appln_id that have weird person_ctry_codes
    data %>% filter(!is.na(person_ctry_code)) %>% filter(is.na(country)) #1,571
          %>% select(appln_id) %>% distinct() %>% count()
    
    #numer of appln_id that have is.na(person_ctry_codes) #288,619
    data %>% filter(is.na(person_ctry_code) )%>% 
      select(appln_id) %>% distinct() %>% count()
    
    # remove both type of missing values
    data <- data %>% filter(!is.na(country))
    
    # number of unique countries in the data
    length(unique(data$person_ctry_code)) #217
    
# Export pp_wiot.csv----
# save on server:
setwd("D:/Tinnefeld-user6/Data/5_output_data") 
write_csv(data, "pp_wiot.csv")




# Statistics----

#*********************************some statistics
setwd("D:/Tinnefeld-user6/Rsinks")
sink("5_merge_pp_wiot.txt", append = T)

"---STATISTICS ON PATENTS---"
"GENERAL"
"number of total appln_id in process_patstat"
length(unique(data$appln_id)) #7,085,916
"number of Y02 appln_id in process_patstat"
length(unique(data$appln_id[which(data$Y02 == 1)])) #560,313
"number of Y02P appln_id in process_patstat"
length(unique(data$appln_id[-which(is.na(data$Y02PN))])) #105,718


"BANHOLZER: ABSTRACT_PROCESS"
"% of Banholzer abstract_process appln_id in total dataset"
data %>% 
  select(appln_id, abstract_process) %>% distinct() %>% 
  group_by(abstract_process) %>% count() %>% 
  summarise(percentage = n/length(unique(data$appln_id)))
"% of Banholzer abstract_process appln_id in Y02 dataset"
data %>% filter(Y02 == 1) %>% 
  select(appln_id, abstract_process) %>% distinct() %>% 
  group_by(abstract_process) %>% count() %>% 
  summarise(percentage = n/length(unique(data$appln_id[which(data$Y02 == 1)])))
"% of Banholzer abstract_process appln_id in Y02 dataset"
data[-which(is.na(data$Y02PN)), ] %>% 
  select(appln_id, abstract_process) %>% distinct() %>% 
  group_by(abstract_process) %>% count() %>% 
  summarise(percentage = n/length(unique(data$appln_id[-which(is.na(data$Y02PN))])))

"BANHOLZER: TITLE_PROCESS"
"% of Banholzer title_process appln_id in total dataset"
data %>% 
  select(appln_id, title_process) %>% distinct() %>% 
  group_by(title_process) %>% count() %>% 
  summarise(percentage = n/length(unique(data$appln_id)))
"% of Banholzer title_process appln_id in Y02 dataset"
data %>% filter(Y02 == 1) %>% 
  select(appln_id, title_process) %>% distinct() %>% 
  group_by(title_process) %>% count() %>% 
  summarise(percentage = n/length(unique(data$appln_id[which(data$Y02 == 1)])))
"% of Banholzer title_process appln_id in Y02P dataset"
data[-which(is.na(data$Y02PN)), ] %>% 
  select(appln_id, title_process) %>% distinct() %>% 
  group_by(title_process) %>% count() %>% 
  summarise(percentage = n/length(unique(data$appln_id[-which(is.na(data$Y02PN))])))

"--- APPLN_ID IN COUNTRIES ---"

"number of appln_id in ROW"
data_small %>% filter(country == "ROW") %>% select(appln_id) %>% distinct() %>% count() #231952
"share of appln_id that come from ROW = 0.03273423"

"number of appln_id with person_ctry_code = NA"
length(unique(data_small$appln_id[which(is.na(data_small$person_ctry_code))])) #289305

"number of appln_id that are from EU members"
data_small %>% filter(eu_member == 1) %>% select(appln_id) %>% distinct() %>% count() #1654265
"number of appln_id that are from OECD members"
data_small %>% filter(oecd_member == 1) %>% select(appln_id) %>% distinct() %>% count() #6646985

sink()
#*********************************

# remove ROW and NA countries

data_small <- data_small %>% filter(country != "ROW")
data_small <- data_small %>% filter(!is.na(country))


#*********************************
setwd("D:/Tinnefeld-user6/Rsinks")
sink("5_merge_pp_wiot.txt", append = T)

"--- APPLN_ID IN COUNTRIES excl. ROW and NA ---"

"number of appln_id"
data_small %>% select(appln_id) %>% distinct() %>% count() #6,993,085

"number of patents over time"
data_small %>% select(appln_id, earliest_filing_year) %>% 
  distinct() %>% group_by(earliest_filing_year) %>% count()

"number of Y02 patents over time"
data_small %>% filter(Y02 == 1) %>% select(appln_id, earliest_filing_year) %>% 
  distinct() %>% group_by(earliest_filing_year) %>% count()

"number of Y02P patents over time"
data_small %>% filter(!is.na(Y02PN)) %>% select(appln_id, earliest_filing_year) %>% 
  distinct() %>% group_by(earliest_filing_year) %>% count()
sink()
#*********************************

# Y02 data----
dataY02 <- data %>% 
            filter(Y02 == 1) %>% 
            distinct()


#********************************* some Y02 stats
setwd("D:/Tinnefeld-user6/Rsinks")
sink("5_merge_pp_wiot.txt", append = T)

"----Y02 PATENTS ONLY - STATISTICS----"

"total number of appln_id that are Y02"
dataY02 %>% select(appln_id) %>% distinct() %>% count() #536,785
"number of Y02 patents in ROW"
dataY02 %>% filter(country == "ROW") %>% #16,082
  select(appln_id) %>% distinct() %>% count()
"number of Y02 patents not in ROW"
dataY02 %>% 
  filter(country != "ROW") %>% #530,262
  select(appln_id) %>% distinct() %>% count()
"this means 2.9% of Y02 applications between 2000-2014 are from ROW"

"how many appln_id have no person_ctry_code?"
dataY02 %>% filter(!is.na(person_ctry_code)) %>% select(appln_id) %>% distinct() %>% count()
length(unique(dataY02$appln_id[which(is.na(dataY02$person_ctry_code))])) #14,480
sink()
#*********************************


# Export Y02 pat_publn_id----
  #done to merge with citation table
setwd("D:/Tinnefeld-user6/Data/5_output_data")
pat_publn_id_Y02 <- dataY02 %>% select(pat_publn_id) %>% distinct()
write.csv(pat_publn_id_Y02, "pat_publn_id.csv")

# Export Y02 data----
write.csv(dataY02, "Y02_pp_wiot.csv")

