#*************************************************************************************
#*CREATE UPSTREAMNESS MEASURES AND LABOUR SHARE
#*
#*INPUT DATA: WIOT 2000-2014; 
#*            Socio_Economic_Accounts.xlsx;
#*            6_allPatents_balancedPanel.csv
#*
#*OUTPUT DATA: Upstream measures, L-share
#*             11_Upstream_measures.csv
#*             7_U_Measures_and_L_Share.csv
#*
#*following: Antras 2012 - Measuring the Upstreamness of Produc...
#*************************************************************************************

# Libraries ----
library(readr); library(tidyverse); library(dplyr); library(ggplot2); 
library(gridExtra); library(pscl); library(plm); library(stargazer);
library(matlib); library(readxl)

select <- dplyr::select

#*************************************************************************************
# ANTRAS 2018 & WANG 2017----
# UPSTREAMNESS 
#********************************************

# Data 2000
load("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/original_WIOD_Data/WIOTS_in_R/WIOT2000_October16_ROW.RData")

# make matrix with only country-industry pairs
ci_only <- wiot %>% 
  filter(Country != "TOT" | IndustryCode == "GO") %>% 
  select(-IndustryCode, -IndustryDescription, -Country, 
         -RNr, -Year, -TOT, 
         -colnames(wiot)[endsWith(colnames(wiot), "57")],
         -colnames(wiot)[endsWith(colnames(wiot), "58")],
         -colnames(wiot)[endsWith(colnames(wiot), "59")],
         -colnames(wiot)[endsWith(colnames(wiot), "60")],
         -colnames(wiot)[endsWith(colnames(wiot), "61")])

ci_only <- as.matrix(ci_only)

rownames(ci_only) <- c(colnames(ci_only), "GO")

dim(ci_only) # should be: 2465x2464


# make adjustment weight for changes in inventory
inventory_changes <- wiot %>% 
  filter(Country != "TOT") %>% 
  select(colnames(wiot)[endsWith(colnames(wiot), "61")]) %>%
  rowSums()

inventory_weight <- wiot$TOT[wiot$Country != "TOT"]/
  (wiot$TOT[wiot$Country != "TOT"]-inventory_changes)
# Y(r,i)/(Y(r,i)-N(r,i))
inventory_weight[is.na(inventory_weight)] <- 0


# make Xhat matrix for U_Wang2017
X_matrix <- ci_only[rownames(ci_only) == "GO", ]
X_matrix[which(X_matrix == 0)] <- 0.000000001
X_matrix <- diag(X_matrix)

   # Xhat inverse
     X_matrix_inverse <- solve(X_matrix)

# 1. calculate the A matrix 
A_matrix <- data.frame(matrix(0, 
                              nrow = dim(ci_only)[2], 
                              ncol = dim(ci_only)[2],
                              dimnames = list(colnames(ci_only), 
                                              colnames(ci_only))))


for (i in 1:dim(ci_only)[2]) {
  for (o in 1:dim(ci_only)[2]) {
    
    A_matrix[i,o] <- ci_only[i,o]*inventory_weight[i]/
      ci_only[rownames(ci_only) == "GO", o]
    
    # a_(rs,ij) = Z(rs, ij)*inventory_weight /  Y_(s,j)
    
  }
} 


A_matrix <- A_matrix %>% replace(is.na(.), 0) # replace NA by 0
A_matrix <- as.matrix(A_matrix)

# 2. create vector of Y
Y_vector <- ci_only[rownames(ci_only) == "GO", ]
Y_vector <- as.matrix(Y_vector)


# 3. create identity matrix 
I_matrix <- diag(1, nrow = dim(ci_only)[2], ncol = dim(ci_only)[2])


# 4. Calculate (I-A_matrix)^(-1)*Y

inverse_matrix <- solve(I_matrix - A_matrix)
numerator_matrix <- inverse_matrix %*% Y_vector
rownames(numerator_matrix) <- colnames(Y_vector)

# 5. Calculate Upstreamness Antras

U_Antras2018 <- numerator_matrix/Y_vector
U_Antras2018 <- U_Antras2018 %>% replace(is.na(.), 0) # replace NA by 0
U_Antras2018[which(is.infinite(U_Antras2018))] <- 0   # replace Inf by 0
colnames(U_Antras2018) <- "U_Antras2018"

# 5. Calculate Upstreamness Wang
U_Wang2017 <- X_matrix_inverse %*% inverse_matrix %*% X_matrix %*% rep(1, length(Y_vector))
colnames(U_Wang2017) <- "U_Wang2017"

# 5. Calculate Downstremness Wang
D_Wang2017 <- t(rep(1, length(Y_vector)) %*% inverse_matrix)
colnames(D_Wang2017) <- "D_Wang2017"

U_Antras2018 <- as.data.frame(cbind(Year = 2000,
                                    Country = wiot$Country[wiot$Country != "TOT"],
                                    Industry = wiot$IndustryCode[wiot$Country != "TOT"], 
                                    U_Antras2018 = as.numeric(U_Antras2018),
                                    U_Wang2017 = U_Wang2017,
                                    D_Wang2017 = D_Wang2017))

U_Antras2018$U_Antras2018 <- as.numeric(U_Antras2018$U_Antras2018)

Upstream_measures_all_years <- U_Antras2018

# Years 2001-2014 

setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/original_WIOD_Data/WIOTS_in_R")
for(yearloop in 2001:2014){
  
  # Load data
  load(paste0("WIOT", yearloop, "_October16_ROW.RData"))
  
  # make matrix with only country-industry pairs
  ci_only <- wiot %>% 
    filter(Country != "TOT" | IndustryCode == "GO") %>% 
    select(-IndustryCode, -IndustryDescription, -Country, 
           -RNr, -Year, -TOT, 
           -colnames(wiot)[endsWith(colnames(wiot), "57")],
           -colnames(wiot)[endsWith(colnames(wiot), "58")],
           -colnames(wiot)[endsWith(colnames(wiot), "59")],
           -colnames(wiot)[endsWith(colnames(wiot), "60")],
           -colnames(wiot)[endsWith(colnames(wiot), "61")])
  
  ci_only <- as.matrix(ci_only)
  
  rownames(ci_only) <- c(colnames(ci_only), "GO")
  
  dim(ci_only) # should be: 2465x2464
  
  # make adjustment weight for changes in inventory
  inventory_changes <- wiot %>% 
    filter(Country != "TOT") %>% 
    select(colnames(wiot)[endsWith(colnames(wiot), "61")]) %>%
    rowSums()
  
  inventory_weight <- wiot$TOT[wiot$Country != "TOT"]/
    (wiot$TOT[wiot$Country != "TOT"]-inventory_changes)
  # Y(r,i)/(Y(r,i)-N(r,i))
  inventory_weight[is.na(inventory_weight)] <- 0
  
  # make Xhat matrix for U_Wang2017
  X_matrix <- ci_only[rownames(ci_only) == "GO", ]
  X_matrix[which(X_matrix == 0)] <- 0.000000001
  X_matrix <- diag(X_matrix)
       # Xhat inverse
       X_matrix_inverse <- solve(X_matrix)
  
  # 1. calculate the A matrix 
  A_matrix <- data.frame(matrix(0, 
                                nrow = dim(ci_only)[2], 
                                ncol = dim(ci_only)[2],
                                dimnames = list(colnames(ci_only), 
                                                colnames(ci_only))))
  
  
  for (i in 1:dim(ci_only)[2]) {
    for (o in 1:dim(ci_only)[2]) {
      
      A_matrix[i,o] <- ci_only[i,o]*inventory_weight[i]/
        ci_only[rownames(ci_only) == "GO", o]
      
      # a_(rs,ij) = Z(rs, ij)*inventory_weight /  Y_(s,j)
      
    }
  }   
  
  
  A_matrix <- A_matrix %>% replace(is.na(.), 0) # replace NA by 0
  A_matrix <- as.matrix(A_matrix)
  
  # 2. create vector of Y
  Y_vector <- ci_only[rownames(ci_only) == "GO", ]
  Y_vector <- as.matrix(Y_vector)
  
  
  # 3. create identity matrix
  I_matrix <- diag(1, nrow = dim(ci_only)[2], ncol = dim(ci_only)[2])
  
  
  # 4. Calculate (I-A_matrix)^(-1)*Y
  
  inverse_matrix <- solve(I_matrix - A_matrix)
  numerator_matrix <- inverse_matrix %*% Y_vector
  rownames(numerator_matrix) <- colnames(Y_vector)
  
  # 5. Calculate Upstreamness
  
  U_Antras2018 <- numerator_matrix/Y_vector
  U_Antras2018 <- U_Antras2018 %>% replace(is.na(.), 0) # replace NA by 0
  U_Antras2018[which(is.infinite(U_Antras2018))] <- 0   # replace Inf by 0
  colnames(U_Antras2018) <- "U_Antras2018"
  
  # 5. Calculate Upstreamness Wang
  U_Wang2017 <- X_matrix_inverse %*% inverse_matrix %*% X_matrix %*% rep(1, length(Y_vector))
  colnames(U_Wang2017) <- "U_Wang2017"
  
  # 5. Calculate Downstremness Wang
  D_Wang2017 <- t(rep(1, length(Y_vector)) %*% inverse_matrix)
  colnames(D_Wang2017) <- "D_Wang2017"
  
  U_Antras2018 <- cbind(Year = yearloop,
                        Country = wiot$Country[wiot$Country != "TOT"],
                        Industry = wiot$IndustryCode[wiot$Country != "TOT"],
                        U_Antras2018 = as.numeric(U_Antras2018),
                        U_Wang2017 = U_Wang2017,
                        D_Wang2017 = D_Wang2017)
  
  Upstream_measures_all_years <- rbind(Upstream_measures_all_years,
                                       U_Antras2018)
}

rm(A_matrix, I_matrix, Y_vector, i, o)
Upstream_measures_all_years$U_Antras2018 <- as.numeric(Upstream_measures_all_years$U_Antras2018)

## Export data----

setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new")
write.csv(Upstream_measures_all_years, "11_Upstream_measures.csv")


#*************************************************************************************
# YANG 2020 ----
# UPSTREAMNESS:   Ui = ln(1+VA/GO) - ln(1+F/GO)
#********************************************

# initialise Value added share and Final share vector
Upstream_measures_all_years$VA_share <- NA
Upstream_measures_all_years$F_share <- NA
Upstream_measures_all_years$F_share_inv <- NA

Upstream_measures_all_years$VA_usDollar <- NA
Upstream_measures_all_years$GO_usDollar <- NA

setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/original_WIOD_Data/WIOTS_in_R")
for(yearloop in 1:15){
  year <- 2000:2014
  # Import data 
  load(paste0("WIOT", year[yearloop], "_October16_ROW.RData"))
  
  # make adjustment weight for changes in inventory
  inventory_changes <- wiot %>% 
    filter(Country != "TOT") %>% 
    select(colnames(wiot)[endsWith(colnames(wiot), "61")]) %>%
    rowSums()
  
  inventory_weight <- wiot$TOT[wiot$Country != "TOT"]/
    (wiot$TOT[wiot$Country != "TOT"]-inventory_changes)
  # Y(r,i)/(Y(r,i)-N(r,i))
  inventory_weight[is.na(inventory_weight)] <- 0
  
  # Calculate VA_usDollar
  Upstream_measures_all_years$VA_usDollar[(1 + dim(ci_only)[2]*(yearloop-1)):
                                         (dim(ci_only)[2]*(yearloop))] <- 
    c(t(wiot[wiot$IndustryCode == "VA", 6:(dim(ci_only)[2]+5)]))
  
  # Calculate GO_usDollar
  Upstream_measures_all_years$GO_usDollar[(1 + dim(ci_only)[2]*(yearloop-1)):
                                            (dim(ci_only)[2]*(yearloop))] <- 
    c(t(wiot[wiot$IndustryCode == "GO",  6:(dim(ci_only)[2]+5)]))
  
  # Calculate VA_share
  Upstream_measures_all_years$VA_share[(1 + dim(ci_only)[2]*(yearloop-1)):
                                         (dim(ci_only)[2]*(yearloop))] <- 
    c(t(wiot[wiot$IndustryCode == "VA", 6:(dim(ci_only)[2]+5)]))/
    c(t(wiot[wiot$IndustryCode == "GO",  6:(dim(ci_only)[2]+5)]))
  
  # Calculate F_share
  F_consump <- wiot %>% 
    filter(Country != "TOT") %>% 
    select(colnames(wiot)[endsWith(colnames(wiot), "57")],
           colnames(wiot)[endsWith(colnames(wiot), "58")],
           colnames(wiot)[endsWith(colnames(wiot), "59")]) %>%
    rowSums()
  
  # Consumption*inventory weight:
  F_consump_inv <- F_consump*inventory_weight
  
  Upstream_measures_all_years$F_share[(1 + dim(ci_only)[2]*(yearloop-1)):
                                        (dim(ci_only)[2]*(yearloop))] <- 
    F_consump/wiot$TOT[wiot$Country != "TOT"]
  
  # For F*inventory weight:
  Upstream_measures_all_years$F_share_inv[(1 + dim(ci_only)[2]*(yearloop-1)):
                                            (dim(ci_only)[2]*(yearloop))] <- 
    F_consump_inv/wiot$TOT[wiot$Country != "TOT"]
}
rm(year, yearloop, ci_only)

Upstream_measures_all_years <- Upstream_measures_all_years %>% 
  replace(is.na(.), 0) 

Upstream_measures_all_years$F_share[which(
  is.infinite(Upstream_measures_all_years$F_share))] <-0

# For F*inventory weight:
Upstream_measures_all_years$F_share_inv[which(
  is.infinite(Upstream_measures_all_years$F_share_inv))] <-0

Upstream_measures_all_years$U_Yang2020 <- 
  log(1 + Upstream_measures_all_years$VA_share) - 
  log(1 + Upstream_measures_all_years$F_share)
# Those industries with high negative VA are in B and H53, 
# >>> hence doesn't matter

# For F*inventory weight: 
#(SVN has negative F_share_inv for C19 most years)
Upstream_measures_all_years$U_Yang2020_inv <- 
  sign(Upstream_measures_all_years$VA_share)*
  log(1 + abs(Upstream_measures_all_years$VA_share)) - 
  sign(Upstream_measures_all_years$F_share_inv)*
  log(1 + abs(Upstream_measures_all_years$F_share_inv))


## Export data----

setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new")
write.csv(Upstream_measures_all_years, "11_Upstream_measures.csv")


#*************************************************************************************
# Specialisation index ----
# country share of value added compared to world share
#********************************************

data <- read_csv("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new/11_Upstream_measures.csv")
data <- data %>% dplyr::select(-...1)

setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/original_WIOD_Data/WIOTS_in_R")


# For the year 2000
load(paste0("WIOT", 2000, "_October16_ROW.RData"))

Specialisation <- wiot %>% select(IndustryCode, Country, RNr, Year) %>% filter(Country != "TOT")
Specialisation$Speci_index <- NA


for (country in 1:(length(unique(wiot$Country))-1)) {
  
  for (industry in 1:56) {
    
    Specialisation$Speci_index[Specialisation$Country == unique(wiot$Country)[country] &
                                 Specialisation$RNr == industry] <- 
      #national share
      (wiot[wiot$IndustryCode == "VA", 
            paste0(unique(wiot$Country)[country], unique(wiot$RNr)[industry])] /
         sum(wiot[wiot$IndustryCode == "VA",
                  which(substr(colnames(wiot), 1, 3) == unique(wiot$Country[country]))[1:56]])) / 
      #global share  
      (sum(wiot[wiot$IndustryCode == "VA", 
                which(substr(colnames(wiot),4,6) == industry)]) /
         sum(wiot[wiot$IndustryCode == "VA",
                  which(substr(colnames(wiot), 4,6) %in% paste(1:56))]))
    
  }
}

Speci_allyears <- Specialisation

# For all other years 
for(yearloop in 1:14){
  year <- 2001:2014
  # Import data 
  load(paste0("WIOT", year[yearloop], "_October16_ROW.RData"))
  
  Specialisation <- wiot %>% select(IndustryCode, Country, RNr, Year) %>% filter(Country != "TOT")
  Specialisation$Speci_index <- NA

  
  for (country in 1:(length(unique(wiot$Country))-1)) {
    
    for (industry in 1:56) {
      
      Specialisation$Speci_index[Specialisation$Country == unique(wiot$Country)[country] &
                             Specialisation$RNr == industry] <- 
      #national share
      (wiot[wiot$IndustryCode == "VA", 
            paste0(unique(wiot$Country)[country], unique(wiot$RNr)[industry])] /
       sum(wiot[wiot$IndustryCode == "VA",
                 which(substr(colnames(wiot), 1, 3) == unique(wiot$Country[country]))[1:56]])) / 
      #global share  
      (sum(wiot[wiot$IndustryCode == "VA", 
                which(substr(colnames(wiot),4,6) == industry)]) /
           sum(wiot[wiot$IndustryCode == "VA",
                    which(substr(colnames(wiot), 4,6) %in% paste(1:56))]))
      
    }
  }
  
Speci_allyears <- rbind(Speci_allyears, Specialisation)

}

#clean up and merge
Speci_allyears <- Speci_allyears %>% select(-RNr)


data <- merge(data, Speci_allyears, 
              by.x = c("Country", "Industry", "Year"), 
              by.y = c("Country", "IndustryCode", "Year"))

rm(Specialisation, industry, country, year, yearloop, wiot, Speci_allyears)

## Export data----

setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new")
write.csv(data, "11_Upstream_measures.csv")


#*************************************************************************************
# Relative Upstreamness ----
# Country Industries upstreamness relative to the global upstreamness of that industry
#********************************************

data <- read_csv("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new/11_Upstream_measures.csv")
data <- data %>% dplyr::select(-...1)

data$UD_Wang2017 <- data$U_Wang2017/data$D_Wang2017

#get relative upstreamness of country industry compared to global average
average <- data %>% group_by(Industry, Year) %>% summarise(Rel_U_Wang = sum(UD_Wang2017)/length(unique(data$Country)))
data <- merge(data, average, by = c("Industry", "Year"), all.x = TRUE)
data$Rel_U_Wang <- data$UD_Wang2017/data$Rel_U_Wang

rm(average)

## Export data----

setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new")
write.csv(data, "11_Upstream_measures.csv")

#*************************************************************************************
# Industry-level Upstreamness ----
# mean of upstreamness of an industry
#********************************************

setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new")
data <- read.csv("11_Upstream_measures.csv")

data <- data %>% group_by(Year, Industry) %>% 
  mutate(UD_mean_industry = mean(UD_Wang2017))

## Export data----
setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new")
write.csv(data, "11_Upstream_measures.csv")


#*************************************************************************************
# Merge SEA ----
# Socio economic accounts data from WIOD project 
#********************************************

# import data
sea_data <- read_excel("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/original_WIOD_Data/Socio_Economic_Accounts.xlsx", 
                       sheet = "DATA")

data <- read_csv("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new/11_Upstream_measures.csv")
data <- data %>% dplyr::select(-...1)

# make into panel data
sea_data <- pivot_longer(sea_data, c(paste(2000:2014, sep = "")), 
                         names_to = "Year")
sea_data <- pivot_wider(sea_data, 
                        id_cols = c(Year, country, description, code),
                        names_from = variable, 
                        values_from = value)


# merge with Upstream measures
data <- merge(data, sea_data, 
              by.x = c("Year", "Country", "Industry"),
              by.y = c("Year", "country", "code"),
              all.x = TRUE)
data$Year <- as.numeric(data$Year)



## L-share Measures----

# explanations of variables: first sheet in Socio_Economic_Accounts.xlsx
data$LabourComp_VA <- data$LAB/data$VA
data$CapitalComp_VA_noadj <- data$CAP/data$VA
data$CapitalStock_VA_noadj <- data$K/data$VA
data$CapitalStock <- data$K
data$CapitalComp <- data$CAP
data$LabourComp <- data$LAB
data$VA_noadj <- data$VA
data$EmployeeComp_VA <- data$COMP/data$VA
data$Person_engaged <- data$EMP
data$EmployeeNumb_VA_noadj <- data$EMPE/data$VA
data$EmployeeHours_VA_noadj <- data$H_EMPE/data$VA
data$LabourComp_CapitalComp <- data$LAB/data$CAP
data$EmployeeNumb_VA <- data$EMPE/data$VA_usDollar
data$EmployeeHours_VA <- data$H_EMPE/data$VA_usDollar
data$VA_vol_index <- data$VA_QI
data$VA_price_level <- data$VA_PI
data$GO_vol_index <- data$GO_QI
data$GO_price_level <- data$GO_PI
data$II_vol_index <- data$II_QI
data$II_price_level <- data$II_PI
data$EmployeeHours_VA_vol_index <- data$H_EMPE/data$VA_vol_index




data <- data %>% 
  select(Year, Country, Industry, description, 
         U_Antras2018, U_Yang2020, U_Yang2020_inv, Rel_U_Wang, Speci_index,
         U_Wang2017, D_Wang2017, UD_mean_industry,
         VA_share, F_share, F_share_inv,
         VA, GO, VA_usDollar, GO_usDollar,
         LabourComp_VA, CapitalComp_VA_noadj, CapitalStock_VA_noadj, CapitalStock,
         CapitalComp, LabourComp,  LabourComp_CapitalComp,
         EmployeeComp_VA, EmployeeNumb_VA, EmployeeHours_VA, Person_engaged,
         EmployeeNumb_VA_noadj, EmployeeHours_VA_noadj,
         VA_vol_index, VA_price_level, GO_vol_index, GO_price_level, 
         II_vol_index, II_price_level, EmployeeHours_VA_vol_index )

data <- data %>% mutate_each(funs(replace(., is.na(.), 0)))
data <- data %>% mutate_each(funs(replace(., is.infinite(.),0)))

## Export data----

setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new")
write.csv(data, "7_U_Measures_and_L_Share.csv")


#*************************************************************************************
# Merge patent-data ----
# Patent data taken from 6_allPatents_balancedPanel.csv
#********************************************

patent_data <- read_csv("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new/6_allPatents_balancedPanel.csv")
patent_data <- patent_data %>% select(-...1)

patent_data <- patent_data %>% 
  select(earliest_filing_year, person_ctry_code, iso_alpha3, 
         IndustryCode, IndustryDescription,
         eu_member, rgdpo, pop, hc, rtfpna, emp,
         PA_global, PA_c, PA_industry, PA_c_i,
         Pshare_mean, Pshare_mean_weighted, Pshare5_mean, Pshare_mean5_weighted, 
         pu_share_2ind_mean, pu_share_2ind_mean_weighted, pu_share_5ind_mean, pu_share_5ind_mean_weighted,
         PP_title_c_i, PP_abstract_c_i, UP_title_c_i, UP_abstract_c_i,
         colnames(patent_data)[startsWith(colnames(patent_data), "Y02")],
         colnames(patent_data)[grepl("grey", colnames(patent_data))],
         colnames(patent_data)[grepl("dirty", colnames(patent_data))],
         colnames(patent_data)[grepl("green", colnames(patent_data))],
         colnames(patent_data)[grepl("Y0", colnames(patent_data))],
         )


patent_data <- merge(patent_data, data, 
                       by.x = c("earliest_filing_year", "iso_alpha3", "IndustryCode"),
                       by.y = c("Year", "Country", "Industry"), all.x = T)

patent_data <- patent_data %>% select(-description)

stargazer(cor(cbind(VA = patent_data$VA, GO = patent_data$GO, 
                    U_A = patent_data$U_Antras2018, U_Y = patent_data$U_Yang2020, 
                    U_Y_inv = patent_data$U_Yang2020_inv, 
                    VA_s = patent_data$VA_share, 
                    F_s = patent_data$F_share, F_s_inv = patent_data$F_share_inv,
                    U_W = patent_data$U_Wang2017, D_W = patent_data$D_Wang2017, 
                    U_i_mean = patent_data$UD_mean_industry)),
          type = "text")

## Export data ----

setwd("C:/Users/franziska.tinnefeld/OneDrive - Universit Cattolica del Sacro Cuore/Paper1/Data/new")
write.csv(patent_data, "7_U_Measures_and_L_Share.csv")
rm(sea_data, data)
