#******************************************************************************************************
#*Patent statistics for data till 2010 ONLY GRANTED
#*
#*IMPORT:pp_wiot.csv
#*
#*EXPORT: patent_stats_till2010_granted.txt
#*
#******************************************************************************************************
# Libraries----

#sapply(c("dplyr", "magrittr", "readr", "haven"), install.packages)
library(dplyr); library(magrittr); library(readr); library(haven); library(readxl); library(ggplot2);
library(data.table); library(tidyr); library(stargazer)
#******************************************************************************************************

# Set-up----

## Load Data----

### pp_wiot.csv data---- 
data <- read_csv("D:/Tinnefeld-user6/Data/5_output_data/pp_wiot.csv")

df <- data[!(data$person_ctry_code %in% c("RU", "TR", "LU", "CY", "MT")), ]

data <- df[df$earliest_filing_year < 2011,]

data <- data[, colnames(data)[!startsWith(colnames(data), "gre")]]

data <- data %>% filter(granted == 1)

## Country Groups----

# Europe
data$Europe_EW <- 0
data$Europe_EW[which(data$iso_alpha3 %in% 
                       c("BGR", "CYP", "CZE", "EST", "GRC", "HRV", 
                         "HUN", "LTU", "LVA", "MLT", "POL", "ROU", 
                         "RUS", "SVK", "SVN" ))] <- "east"
data$Europe_EW[which(data$iso_alpha3 %in% 
                       c("AUT", "BEL", "CHE", "DEU", "DNK", "ESP", 
                         "FIN", "FRA", "GBR", "IRL", "ITA", "LUX", 
                         "NLD", "NOR", "PRT", "SWE" ))] <- "west"

data$Europe_EW[which(data$iso_alpha3 %in%
                       c("AUS", "CAN", "USA"))] <- "otherwest"

data$Europe_EW[which(data$iso_alpha3 %in%
                       c("CHN", "IND", "JPN", "KOR", "TWN", "IDN"))] <- "asia"

data$Europe_EW <- as.factor(data$Europe_EW)

# Asia
data$Asia <- 0
data$Asia[which(data$iso_alpha3 %in% 
                  c("CHN", "IDN", "IND", "JPN", "KOR", "TWN"))] <- "asia"
data$Asia <- as.factor(data$Asia)


# Groups
data$Group <- "AU, CA, US"
data$Group[data$Europe_EW == "east"] <- "east Europe"
data$Group[data$Europe_EW == "west"] <- "west Europe"
data$Group[data$Europe_EW == "asia"] <- "Asia"
data$Group[data$Europe_EW == "0"] <- "BR, MX"
#------------------------------------
setwd("//tsclient/C/Users/franziska.tinnefeld/OneDrive - Universit? Cattolica del Sacro Cuore/Paper1/Skripts_all")
sink("patent_stats_till2010_granted.txt")

# Statistics----

## Basic stats----
# unique applications
length(unique(data$appln_id)) #6,326,209 without 2014

data %>% group_by(Europe_EW) %>% select(appln_id) %>% 
  distinct() %>% count() %>% summarise(n/length(unique(data$appln_id)))

# unique countries
length(unique(data$person_ctry_code)) #38


# unique years
length(unique(data$earliest_filing_year)) #14

# unique Y02 patents
data %>% select(appln_id, Y02) %>% distinct() %>% #493,260
  filter(Y02==1)%>% count()

# unique Y02P patents
data %>% select(appln_id, Y02PN) %>% distinct() %>% #98,103
  filter(Y02PN!=0) %>% count()

# unique pure process patents
data %>% filter(process_ratio_2_ind == 1) %>% select(appln_id) %>% #697,032
  distinct() %>% count() 
# unique pure product patents
data %>% filter(process_ratio_2_ind == 0) %>% select(appln_id) %>% #2,972,761
  distinct() %>% count()

# number of applicants per patent
data %>% select(appln_id, nb_applicants) %>% distinct() %>% #1.885199
  summarise(mean(nb_applicants))

stargazer(cbind(Group = c("MX, BR", "Asia", "east Europe", "AU, CA, US", "west Europe"),
                data %>% group_by(Europe_EW) %>% 
                  select(appln_id, nb_applicants) %>%
                  distinct() %>% 
                  summarise("Applicants" = round(mean(nb_applicants), 3)) %>% 
                  select("Applicants"),
                data %>% group_by(Europe_EW) %>% 
                  select(appln_id, nb_inventors) %>%
                  distinct() %>% 
                  summarise("Inventors" = round(mean(nb_inventors), 3)) %>% 
                  select("Inventors")),
          type = "text", summary = F,
          title = "Average number of applicants and inventors on patent applications used in the analysis across different country groups",
          font.size = "footnotesize",
          label = "tab:A_I_patentstat")

data %>% select(appln_id, nb_inventors) %>% distinct() %>% #2.658604
  summarise(mean(nb_inventors))

# DOCDB----
# DOCDB average family size
data %>% select(appln_id, docdb_family_size) %>% distinct() %>% #5.631155
  summarise(mean(docdb_family_size))

data %>% group_by(Europe_EW) %>% select(appln_id, docdb_family_size) %>% distinct() %>%
  summarise(mean(docdb_family_size)) # West europe largest, Asia smallest

# Applicant & Inventor----
# average number of inventors and applicants per country
cbind(data %>% group_by(person_ctry_code) %>% select(appln_id, nb_inventors) %>% 
        distinct() %>% summarise(mean(nb_inventors)),
      data %>% group_by(person_ctry_code) %>% select(appln_id, nb_applicants) %>% 
        distinct() %>% summarise(mean(nb_applicants)))


# 
d <- data %>% filter(nb_inventors > 1) %>% 
  select(person_ctry_code, Europe_EW, appln_id) %>% distinct()

d$WE <- 0
d$WE[d$Europe_EW == "west"] <- 1
d$EE <- 0
d$EE[d$Europe_EW == "east"] <- 1
d$AC <- 0
d$AC[d$Europe_EW == "asia"] <- 1
d$WA <- 0
d$WA[d$Europe_EW == "otherwest"] <- 1
d$LA <- 0
d$LA[d$Europe_EW == 0] <- 1

# applications with more than one inventor
length(unique(d$appln_id)) #4,248,267
length(unique(d$appln_id))/length(unique(data$appln_id)) #0.6715344
# 67% of patents have more than one inventor


# inventors form the same countries
samecountry <- d %>% group_by(appln_id) %>% count() %>% 
  filter(n == 1)


length(unique(samecountry$appln_id)) # 3,557,246
length(unique(samecountry$appln_id))/length(unique(data$appln_id)) # 0.562303
# 56% of patents have multiple inventors from the same country
# this means that 11% have inventors fro 2 different countries

# remove those appln_id with multiple inventors from the same country
nosame1 <- d[!(d$appln_id %in% unique(samecountry$appln_id)), ]
length(unique(nosame1$appln_id)) #691,021
length(unique(nosame1$appln_id))/length(unique(data$appln_id)) # 0.1092315
# 10.9% of patents have multiple inventors from at least 2 different countries

# with what country group do countries patent?
nosame1 <- nosame1 %>% group_by(appln_id, Europe_EW) %>% count()
nosame1$dummy <- 1

nosame1 <- pivot_wider(nosame1, id_cols = appln_id, values_from = dummy, names_from = Europe_EW) 

nosame <- nosame1%>% 
  group_by(west, otherwest, east, asia, `0`) %>% count()

east <- nosame %>% filter(east == 1)
west <- nosame %>% filter(west == 1)
otherwest <- nosame %>% filter(otherwest == 1)
asia <- nosame %>% filter(asia == 1)
latinas <- nosame %>% filter(`0` == 1)

east$percent <- east$n/sum(east$n)
east %>% filter(percent>0.01)

west$percent <- west$n/sum(west$n)
west %>% filter(percent>0.01)

asia$percent <- asia$n/sum(asia$n)
asia %>% filter(percent>0.01)

otherwest$percent <- otherwest$n/sum(otherwest$n)
otherwest %>% filter(percent>0.01)

latinas$percent <- latinas$n/sum(latinas$n)
latinas %>% filter(percent>0.01)

# are process-shares on patents with collaborations higher or not?
ddd <- data
dat <- ddd %>% select(appln_id, process_ratio_2_ind) %>% distinct()
mean(dat$process_ratio_2_ind[!(dat$appln_id %in% nosame1$appln_id)], na.rm=T)
mean(dat$process_ratio_2_ind[dat$appln_id %in% nosame1$appln_id], na.rm=T)

nocollab <- dat$process_ratio_2_ind[!(dat$appln_id %in% nosame1$appln_id)]
nocollab <- nocollab[complete.cases(nocollab)]
collab <- dat$process_ratio_2_ind[dat$appln_id %in% nosame1$appln_id]
collab <- collab[complete.cases(collab)]
t.test(nocollab, collab) # collaborative patents have a significantly higher process-share

mean(dat$process_ratio_2_ind, na.rm = T)

ddd %>% select(IndustryCode, appln_id, process_ratio_2_ind) %>% distinct() %>% 
  group_by(IndustryCode) %>% summarise(mean(process_ratio_2_ind, na.rm=T))

#------------------------------------------------------------------
# Patens over time----

# over time number of patents
ddd <- data %>% select(appln_id, person_ctry_code, Europe_EW, Group, 
                       earliest_filing_year, process_ratio_2_ind) %>% distinct()

# make data for product, process and mixed patents
product <- ddd[ddd$process_ratio_2_ind == 0,]
process <- ddd[ddd$process_ratio_2_ind == 1,]
mixed <- ddd[ddd$process_ratio_2_ind < 1,]
mixed <- mixed[mixed$process_ratio_2_ind > 0,]

# Figures

#plot1
jpeg(file="plot1_till2010_granted.jpeg")

gridExtra::grid.arrange(
  
  ggplot(ddd %>% group_by(Group, earliest_filing_year) %>% count(), 
         mapping = aes(earliest_filing_year, n/1000, col = Group)) +
    geom_line() +
    theme_minimal() + scale_y_log10() +
    xlab("Year") + ylab("Number of patents (in thousands)"),
  
  ggplot(product %>% group_by(Group, earliest_filing_year) %>% count(), 
         mapping = aes(earliest_filing_year, n/1000, col = Group)) + ylim(0, 110) +
    geom_line() +
    theme_minimal() + theme(legend.position = "none") +
    xlab("Year") + ylab("Pure product patents (in thousands)") + 
    scale_y_log10() ,
  
  ggplot(process %>% group_by(Group, earliest_filing_year) %>% count(), 
         mapping = aes(earliest_filing_year, n/1000, col = Group)) + ylim(0,110) +
    geom_line() +
    theme_minimal() + theme(legend.position = "none") +
    xlab("Year") + ylab("Pure process patents (in thousands)") + 
    scale_y_log10(),
  
  ggplot(mixed %>% group_by(Group, earliest_filing_year) %>% count(), 
         mapping = aes(earliest_filing_year, n/1000, col = Group)) + ylim(0, 110) +
    geom_line() +
    theme_minimal() + theme(legend.position = "none") +
    xlab("Year") + ylab("Mixed patents (in thousands)") +
    scale_y_log10(),
  widths = c(1, 1, 1),
  layout_matrix = rbind(c(1, 1, 1),
                        c(2, 3, 4)))
dev.off()

#plot2
jpeg(file="plot2_till2010_granted.jpeg")
ggplot(ddd %>% group_by(Group, earliest_filing_year) %>% 
         summarise(processshare = mean(process_ratio_2_ind, na.rm=T)),
       mapping = aes(earliest_filing_year, processshare, col = Group)) +
  geom_line() +
  theme_minimal() + theme(legend.position = "none") +
  xlab("Year") + ylab("Process-share of Patents (within means across years)")
dev.off()
# boxplots of percentages


all <- ddd %>% group_by(Group) %>% select(appln_id) %>% distinct() %>% count() %>% ungroup()
prod <- product %>% group_by(Group) %>% select(appln_id) %>% distinct() %>% count() %>% ungroup()
proc <- process %>% group_by(Group) %>% select(appln_id) %>% distinct() %>% count() %>% ungroup()
mix <- mixed %>% group_by(Group) %>% select(appln_id) %>% distinct() %>% count() %>% ungroup()
prod <- prod[1:5,]; proc <- proc[1:5,]; mix <- mix[1:5,]
all <- cbind(all, product = prod$n, process = proc$n, mixed = mix$n)
all %>% select(-n) %>% pivot_longer(!Group, names_to = "Patent", values_to = "count") %>% 
  ggplot(., mapping = aes(y = count, x = Group, fill = Patent)) +
  geom_bar(position="fill", na.rm = T, stat = "identity") +
  theme_minimal() + coord_flip() + 
  ylab("Fraction of the type of patents") +
  xlab("")

sink() 